@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Set
 
 import docker
 
@@ -8,6 +8,13 @@ class PortMapping:
         self.private_port = private_port
         self.public_port = public_port
 
+    def __eq__(self, other):
+        return self.private_port == other.private_port \
+               and self.public_port == other.public_port
+
+    def __hash__(self):
+        return self.private_port + self.private_port
+
     def __repr__(self):
         return '%d:%d' % (self.public_port, self.private_port)
 
@@ -24,7 +31,7 @@ class VolumeMapping:
 
 class Container:
     def __init__(self, name: str, status: str, networks: List[str], image: str,
-                 ports: List[PortMapping] = None,
+                 ports: Set[PortMapping] = None,
                  volumes: List[VolumeMapping] = None):
         self.name = name
         self.status = status
@@ -77,8 +84,8 @@ class ConfigParser:
             image = cinfo['Image']
             networks = [n for n in cinfo['NetworkSettings']['Networks'].keys()]
             networks.sort()
-            ports = [PortMapping(p['PrivatePort'], p['PublicPort'])
-                     for p in cinfo['Ports'] if 'PublicPort' in p.keys()]
+            ports = {PortMapping(p['PrivatePort'], p['PublicPort'])
+                     for p in cinfo['Ports'] if 'PublicPort' in p.keys()}
             volumes = [VolumeMapping(rw=v['RW'], source=v['Source'], destination=v['Destination'])
                        for v in cinfo['Mounts']]
             containers.append(Container(name, status, networks, image, ports, volumes))
